@@ -6,6 +6,7 @@ Created on Mon Sep 21 11:21:23 2020
 """
 
 import nidaqmx
+from nidaqmx._lib import DaqNotFoundError
 from nidaqmx.constants import TerminalConfiguration
 import numpy as np
 
@@ -16,18 +17,22 @@ hwid = ["software"]
 
 
 def get_devices(dev="Dev1"):
-    devices_all = nidaqmx.system.Device(dev).ai_physical_chans
-    devices = [device.name for device in devices_all]
-    '''
-    for device in devices_all:
-        with nidaqmx.Task() as task:
-            task.ai_channels.add_ai_voltage_chan(device.name)
-            r = task.read(number_of_samples_per_channel=1000)
-            if np.mean(r) > 0:
-                devices.append(device)
-    #if you wantecd to test devices
-    '''
-    return devices
+    try:
+        devices_all = nidaqmx.system.Device(dev).ai_physical_chans
+        devices = [device.name for device in devices_all]
+        '''
+        for device in devices_all:
+            with nidaqmx.Task() as task:
+                task.ai_channels.add_ai_voltage_chan(device.name)
+                r = task.read(number_of_samples_per_channel=1000)
+                if np.mean(r) > 0:
+                    devices.append(device)
+        #if you wantecd to test devices
+        '''
+        return devices
+
+    except DaqNotFoundError:
+        return []
 
 
 class instrument():
