@@ -30,7 +30,7 @@ def get_devices():
     devices = []
     for device in devices_all:
         global hwid
-        if device.hwid.split(" ")[1].replace("VID:PID=", "") == hwid:
+        if device.hwid.split(" ")[1].replace("VID:PID=", "") in hwid:
             if test_port(device.name):
                 devices.append(device)
     return devices
