@@ -1,18 +1,19 @@
 # dynamic loading based on Dashboard code
 # Version 3 dynamic loader
 import os
-from pathlib import Path
-from importlib import import_module
-from .generic_base import Instrument
 import warnings
+from importlib import import_module
+from pathlib import Path
+
+from .generic_base import Instrument
+from .instrumenttype import InstrumentType
 
 here = str(Path(__file__).resolve().parent)
 directory_name = here.replace(str(Path(__file__).resolve().parent.parent), "").replace("/", "")  # gross solution
-instruments = {}
 
 for directory in os.scandir(here):
     if directory.is_dir() and not directory.name.__contains__("__"):
-        modules = {}
+        modules = []
         for file in os.listdir(directory):
             dname = str(directory.name).replace(here, "")
             if str(file).__contains__(f"{dname}_"):
@@ -26,22 +27,17 @@ for directory in os.scandir(here):
                     try:
                         function = module.get_devices
                     except:
-                        function = "default"
-                    modules[module.name] = {"name": module.name, "module": module, "hwid": module.hwid,
-                                            "serial": serial, "function": function}
+                        function = None
+                    modules.append(InstrumentType(module.name, module, module.hwid, serial, function))
                 except Exception as ex:
                     print(f"{file} import failed")
                     print(ex)
-                else:
-                    instruments[module.name] = module
         globals()[directory.name] = Instrument(modules=modules, name=directory.name)
     elif directory.name.__contains__("ports"):
         globals()["ports"] = import_module(f"{directory_name}.ports")
-    elif directory.name.__contains__("stellarnet"):
-        globals()["stellarnet"] = import_module(f"{directory_name}.stellarnet")
     elif not directory.name.__contains__("__"):
         file = directory.name
-        if not str(file).__contains__("base"):
+        if not (str(file).__contains__("base") or str(file).__contains__("type")):
             sname = file.replace(".py", "")
             try:
                 module = import_module(f"{directory_name}.{sname}")
@@ -55,9 +51,8 @@ for directory in os.scandir(here):
                     try:
                         function = module.get_devices
                     except:
-                        function = "default"
-                    modules = {
-                        name: {"name": name, "module": module, "hwid": hwid, "serial": serial, "function": function}}
+                        function = None
+                    modules = [InstrumentType(name, module, hwid, serial, function)]
                     globals()[name] = Instrument(modules=modules, name=name)
                 except:
                     name = sname
