@@ -1,4 +1,5 @@
 import elliptec
+import numpy as np
 
 name = "elliptec"
 hwid = ["0403:6015"]
@@ -16,6 +17,7 @@ class instrument:
         self.rotator = elliptec.Motor(port.device)
         self.max_degree = 180
         self.min_degree = -180
+        self.degree = np.mod(self.rotator.get_("position")[1], 360)
 
     def home(self):
         self.degree = 0
